var categoryColors = [
  "#1f77b4", // blue
  "#ff7f0e", // orange
  "#2ca02c", // green
  "#e377c2", // pink
  "#d62728", // red
  "#bcbd22", // lime
  "#9467bd", // purple
  "#8c564b", // brown
  "#7f7f7f", // grey
  "#17becf", // cyan
  "#aec7e8", // light blue
  "#ffbb78", // light orange
  "#98df8a", // light green
  "#f7b6d2", // light pink
  "#ff9896", // light red
  "#dbdb8d", // light lime
  "#c5b0d5", // light purple
  "#c49c94", // light brown
  "#c7c7c7", // light grey
  "#9edae5" // light cyan
];

var colorScales = {
  "WhGn": [
      "#ffffff",
      "#2ca02c"
    ],
  "GnWh": [
      "#2ca02c",
      "#ffffff"
    ],
  "WhRd": [
      "#ffffff",
      "#d62728"
    ],
  "RdWh": [
      "#d62728",
      "#ffffff"
    ],
  "WhBk": [
      "#ffffff",
      "#000000"
    ],
  "BkWh": [
      "#000000",
      "#ffffff"
    ],
  "WhBu": [
      "#ffffff",
      "#1f77b4"
    ],
  "BuWh": [
      "#1f77b4",
      "#ffffff"
    ],
  "GnWhRd": [
      "#2ca02c",
      "#ffffff",
      "#d62728"
    ],
  "RdWhGn": [
      "#d62728",
      "#ffffff",
      "#2ca02c"
    ],
  "BkWhRd": [
      "#000000",
      "#ffffff",
      "#d62728"
    ],
  "RdWhBk": [
      "#d62728",
      "#ffffff",
      "#000000"
    ],
  "BuWhRd": [
      "#1f77b4",
      "#ffffff",
      "#d62728"
    ],
  "RdWhBu": [
      "#d62728",
      "#ffffff",
      "#1f77b4"
    ],
  "YlWhBu": [
      "#bcbd22",
      "#ffffff",
      "#1f77b4"
    ],
  "BuWhYl": [
      "#1f77b4",
      "#ffffff",
      "#bcbd22"
    ],
  "GnBkRd": [
      "#2ca02c",
      "#000000",
      "#d62728"
    ],
  "RdBkGn": [
      "#d62728",
      "#000000",
      "#2ca02c"
    ],
  "BkRd": [
      "#000000",
      "#d62728"
    ],
  "RdBk": [
      "#d62728",
      "#000000"
    ],
  "BuRd": [
      "#1f77b4",
      "#d62728"
    ],
  "RdBu": [
      "#d62728",
      "#1f77b4"
    ],
  "YlBu": [
      "#bcbd22",
      "#1f77b4"
    ],
  "BuYl": [
      "#1f77b4",
      "#bcbd22"
    ],
  "BuGn": ["#6720D6", "#0BD638"],
  "PiGn": ["#D6249D", "#70D661"],
  "YlPi": ["#D6C30C", "#8A013C"],
  "BuPi": ["#24D6C0", "#D618CC"],
  "OrPu": ["#D68706", "#811CD6"],
  "PiWh": ["#D618CC", "#FFFFFF"],
  "OrWh": ["#D68D01", "#FFFFFF"],
  "YlWh": ["#D6D31F", "#FFFFFF"]
};
